@@ -18,9 +18,9 @@ from sqlfluff.core.parser import (
     Nothing,
     OneOf,
     OptionallyBracketed,
-    ParseMode,
     Ref,
     RegexLexer,
+    RegexParser,
     Sequence,
     StringLexer,
     StringParser,
@@ -32,7 +32,21 @@ from sqlfluff.dialects import dialect_postgres as postgres
 
 ansi_dialect = load_raw_dialect("ansi")
 postgres_dialect = load_raw_dialect("postgres")
-duckdb_dialect = postgres_dialect.copy_as("duckdb")
+duckdb_dialect = postgres_dialect.copy_as(
+    "duckdb",
+    formatted_name="DuckDB",
+    docstring="""**Default Casing**: DuckDB stores all identifiers in the case
+they were defined, however all identifier resolution is case-insensitive (when
+unquoted, and more unusually, *also when quoted*). See the
+`DuckDB Identifiers Documentation`_ for more details.
+
+**Quotes**: String Literals: ``''``, Identifiers: ``""`` or ``''``
+
+The dialect for `DuckDB <https://duckdb.org/>`_.
+
+.. _`DuckDB Identifiers Documentation`: https://duckdb.org/docs/sql/dialect/keywords_and_identifiers
+""",  # noqa: E501
+)
 
 duckdb_dialect.sets("reserved_keywords").update(
     [
@@ -47,8 +61,10 @@ duckdb_dialect.sets("unreserved_keywords").update(
     [
         "ANTI",
         "ASOF",
+        "MACRO",
         "POSITIONAL",
         "SEMI",
+        "STRUCT",
         "VIRTUAL",
     ]
 )
@@ -58,6 +74,12 @@ duckdb_dialect.add(
 )
 
 duckdb_dialect.replace(
+    FunctionNameIdentifierSegment=RegexParser(
+        r"[A-Z_][A-Z0-9_$]*",
+        CodeSegment,
+        type="function_name_identifier",
+        anti_template=r"^(STRUCT|UNION|ENUM)$",
+    ),
     DivideSegment=OneOf(
         StringParser("//", BinaryOperatorSegment),
         StringParser("/", BinaryOperatorSegment),
@@ -107,10 +129,7 @@ duckdb_dialect.replace(
     # Uses grammar for LT06 support
     ColumnsExpressionGrammar=Sequence(
         Ref("ColumnsExpressionFunctionNameSegment"),
-        Bracketed(
-            Ref("ColumnsExpressionFunctionContentsSegment"),
-            parse_mode=ParseMode.GREEDY,
-        ),
+        Ref("ColumnsExpressionFunctionContentsSegment"),
     ),
     # Matching postgres lower casefold, as it is case-insensitive
     QuotedIdentifierSegment=TypedParser(
@@ -119,6 +138,7 @@ duckdb_dialect.replace(
     SingleQuotedIdentifierSegment=TypedParser(
         "single_quote", IdentifierSegment, type="quoted_identifier", casefold=str.lower
     ),
+    ListComprehensionGrammar=Ref("ListComprehensionExpressionSegment"),
 )
 
 duckdb_dialect.insert_lexer_matchers(
@@ -154,6 +174,37 @@ duckdb_dialect.patch_lexer_matchers(
 )
 
 
+class StructTypeSegment(ansi.StructTypeSegment):
+    """Expression to construct a STRUCT datatype."""
+
+    match_grammar = Sequence(
+        "STRUCT",
+        Ref("StructTypeSchemaSegment", optional=True),
+    )
+
+
+class StructTypeSchemaSegment(BaseSegment):
+    """Expression to construct the schema of a STRUCT datatype."""
+
+    type = "struct_type_schema"
+    match_grammar = Bracketed(
+        Delimited(  # Comma-separated list of field names/types
+            Sequence(
+                OneOf(
+                    # ParameterNames can look like Datatypes so can't use
+                    # Optional=True here and instead do a OneOf in order
+                    # with DataType only first, followed by both.
+                    Ref("DatatypeSegment"),
+                    Sequence(
+                        Ref("ParameterNameSegment"),
+                        Ref("DatatypeSegment"),
+                    ),
+                ),
+            ),
+        ),
+    )
+
+
 class ColumnConstraintSegment(ansi.ColumnConstraintSegment):
     """A column option; each CREATE TABLE column can have 0 or more.
 
@@ -317,11 +368,30 @@ class ColumnsExpressionFunctionContentsSegment(
     https://duckdb.org/docs/sql/expressions/star#columns-expression
     """
 
-    type = "columns_expression"
-    match_grammar = OneOf(
-        Ref("WildcardExpressionSegment"),
-        Ref("QuotedLiteralSegment"),
-        Ref("LambdaExpressionSegment"),
+    type = "function_contents"
+    match_grammar = Sequence(
+        Bracketed(
+            OneOf(
+                Ref("WildcardExpressionSegment"),
+                Ref("QuotedLiteralSegment"),
+                Ref("LambdaExpressionSegment"),
+            ),
+        ),
+    )
+
+
+class NamedArgumentSegment(postgres.NamedArgumentSegment):
+    """Named argument to a function.
+
+    Some functions may use a `walrus operator`.
+    e.g. https://duckdb.org/docs/sql/functions/struct#struct_packname--any-
+    """
+
+    type = "named_argument"
+    match_grammar = Sequence(
+        Ref("NakedIdentifierSegment"),
+        OneOf(Ref("RightArrowSegment"), Ref("WalrusOperatorSegment")),
+        Ref("ExpressionSegment"),
     )
 
 
@@ -343,6 +413,24 @@ class LambdaExpressionSegment(BaseSegment):
     )
 
 
+class ListComprehensionExpressionSegment(BaseSegment):
+    """A list comprehension expression in duckdb.
+
+    https://duckdb.org/docs/sql/functions/list#list-comprehension
+    """
+
+    type = "list_comprehension"
+    match_grammar = Bracketed(
+        Ref("ExpressionSegment"),
+        "FOR",
+        Ref("ParameterNameSegment"),
+        "IN",
+        Ref("ExpressionSegment"),
+        Sequence("IF", Ref("ExpressionSegment"), optional=True),
+        bracket_type="square",
+    )
+
+
 class SelectStatementSegment(ansi.SelectStatementSegment):
     """A duckdb `SELECT` statement including optional Qualify.
 
@@ -638,3 +726,68 @@ class SimplifiedUnpivotExpressionSegment(BaseSegment):
         Ref("OrderByClauseSegment", optional=True),
         Ref("LimitClauseSegment", optional=True),
     )
+
+
+class CreateViewStatementSegment(postgres.CreateViewStatementSegment):
+    """An `Create VIEW` statement.
+
+    https://duckdb.org/docs/sql/statements/create_view.html
+    """
+
+    type = "create_view_statement"
+
+    match_grammar = Sequence(
+        "CREATE",
+        Ref("OrReplaceGrammar", optional=True),
+        Ref("TemporaryGrammar", optional=True),
+        "VIEW",
+        Ref("IfNotExistsGrammar", optional=True),
+        Ref("TableReferenceSegment"),
+        Ref("BracketedColumnReferenceListGrammar", optional=True),
+        "AS",
+        OneOf(
+            OptionallyBracketed(Ref("SelectableGrammar")),
+            Ref("ValuesClauseSegment"),
+        ),
+    )
+
+
+class CreateFunctionStatementSegment(postgres.CreateFunctionStatementSegment):
+    """A `CREATE MACRO` or `CREATE FUNCTION` statement.
+
+    https://duckdb.org/docs/sql/statements/create_macro
+    """
+
+    match_grammar = Sequence(
+        "CREATE",
+        Ref("OrReplaceGrammar", optional=True),
+        Ref("TemporaryGrammar", optional=True),
+        OneOf("MACRO", "FUNCTION"),
+        Ref("FunctionNameSegment"),
+        Ref("FunctionParameterListGrammar"),
+        "AS",
+        OneOf(
+            Sequence("TABLE", Indent, Ref("SelectableGrammar"), Dedent),
+            Ref("ExpressionSegment"),
+        ),
+    )
+
+
+class CreateTypeStatementSegment(postgres.CreateTypeStatementSegment):
+    """A `CREATE TYPE` statement.
+
+    https://duckdb.org/docs/sql/statements/create_type.html
+    """
+
+    match_grammar = Sequence(
+        "CREATE",
+        "TYPE",
+        Ref("DatatypeIdentifierSegment"),
+        "AS",
+        OneOf(
+            Ref("DatatypeIdentifierSegment"),
+            Sequence("ENUM", Bracketed(Delimited(Ref("QuotedLiteralSegment")))),
+            Ref("StructTypeSegment"),
+            Sequence("UNION", Ref("StructTypeSchemaSegment")),
+        ),
+    )
