@@ -14,6 +14,7 @@ from sqlfluff.core.parser import (
     CompositeComparisonOperatorSegment,
     Dedent,
     Delimited,
+    IdentifierSegment,
     Indent,
     KeywordSegment,
     LiteralSegment,
@@ -38,7 +39,12 @@ from sqlfluff.dialects.dialect_vertica_keywords import (
 )
 
 ansi_dialect = load_raw_dialect("ansi")
-vertica_dialect = ansi_dialect.copy_as("vertica")
+vertica_dialect = ansi_dialect.copy_as(
+    "vertica",
+    formatted_name="Vertica",
+    docstring="""The dialect for
+`Vertica <https://www.vertica.com/documentation/vertica/all/>`_.""",
+)
 
 vertica_dialect.insert_lexer_matchers(
     # Allow ::! operator as in
@@ -90,6 +96,20 @@ vertica_dialect.insert_lexer_matchers(
     before="like_operator",
 )
 
+vertica_dialect.patch_lexer_matchers(
+    [
+        RegexLexer(
+            "double_quote",
+            r'"([^"]|"")*"',
+            CodeSegment,
+            segment_kwargs={
+                "quoted_value": (r'"((?:[^"]|"")*)"', 1),
+                "escape_replacements": [(r'""', '"')],
+            },
+        ),
+    ]
+)
+
 # Set Keywords
 vertica_dialect.update_keywords_set_from_multiline_string(
     "unreserved_keywords", vertica_unreserved_keywords
@@ -456,6 +476,9 @@ vertica_dialect.replace(
             ),
         ),
     ),
+    QuotedIdentifierSegment=TypedParser(
+        "double_quote", IdentifierSegment, type="quoted_identifier", casefold=str.upper
+    ),
 )
 
 
@@ -1813,17 +1836,7 @@ class FunctionSegment(ansi.FunctionSegment):
             # rather than identifiers.
             Sequence(
                 Ref("DatePartFunctionNameSegment"),
-                Bracketed(
-                    Delimited(
-                        Ref("DatetimeUnitSegment"),
-                        Ref(
-                            "FunctionContentsGrammar",
-                            # The brackets might be empty for some functions...
-                            optional=True,
-                        ),
-                    ),
-                    parse_mode=ParseMode.GREEDY,
-                ),
+                Ref("DateTimeFunctionContentsSegment"),
             ),
         ),
         Ref("ColumnsExpressionGrammar"),
@@ -1837,14 +1850,7 @@ class FunctionSegment(ansi.FunctionSegment):
                         Ref("ValuesClauseSegment"),
                     ),
                 ),
-                Bracketed(
-                    Ref(
-                        "FunctionContentsGrammar",
-                        # The brackets might be empty for some functions...
-                        optional=True,
-                    ),
-                    parse_mode=ParseMode.GREEDY,
-                ),
+                Ref("FunctionContentsSegment"),
             ),
             AnySetOf(Ref("PostFunctionGrammar")),
         ),
